package Catmandu::BibTeX;

our $VERSION = '0.08';

1;

__END__

=head1 NAME

Catmandu::BibTeX - Catmandu modules for working with BibTeX data

=head1 STATUS

=begin markdown

# STATUS

[![Build Status](https://travis-ci.org/LibreCat/Catmandu-BibTeX.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-BibTeX)
[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-BibTeX/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-BibTeX)
[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-BibTeX.png)](http://cpants.cpanauthors.org/dist/Catmandu-BibTeX)

=end markdown

=head1 MODULES

=over

=item * L<Catmandu::Importer::BibTeX>

=item * L<Catmandu::Exporter::BibTeX>

=back

=head1 AUTHOR

Nicolas Steenlant C<< <nicolas.steenlant at ugent.be> >>

=head1 CONTRIBUTORS

Vitali Peil C<< <vitali.peil at uni-bielefeld.de> >>

Jakov Voss C<< <voss at gbv.de> >>

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut
